@@ -1,4 +1,5 @@
 #!/usr/bin/python
+# flake8: noqa
 # pep8.py - Check Python source code formatting, according to PEP 8
 # Copyright (C) 2006 Johann C. Rocholl <johann@rocholl.net>
 #
@@ -104,6 +105,8 @@ from optparse import OptionParser
 from keyword import iskeyword
 from fnmatch import fnmatch
 
+from flake8.util import skip_line
+
 DEFAULT_EXCLUDE = '.svn,CVS,.bzr,.hg,.git'
 DEFAULT_IGNORE = ['E24']
 
@@ -935,7 +938,7 @@ class Checker(object):
         """
         Report an error, according to options.
         """
-        if self.physical_line.strip().lower().endswith('# noqa'):
+        if skip_line(self.physical_line):
             return
         if options.quiet == 1 and not self.file_errors:
             message(self.filename)
